# 要件定義書
# Reveal.jsを用いたプレゼンテーション資料作成の要件定義

## 目的
- {prompt}をお題とする
- index.htmlのみ出力
- Reveal.jsを使用して、指定されたお題に関するプレゼンテーション資料を作成する

## 機能要件
- JavaScriptの資産を最大限活用し、おしゃれなプレゼンテーションを作成する
- ふざけた内容を真面目かつ徹底的に議論する
- スライド枚数は10枚とする
- コードは一切省略せずに記載する
- 100万円で売れる価値の高いプレゼンテーションを目指す
- アニメーションを取り入れ、リッチな見た目にする
- 画像はunsplashから取得する
- 色は白を基調としたカラフルな色使いにする
- 様々なレイアウトを使用し、アニメーションを活用する
- おしゃれな日本語フォントを使用する

## 非機能要件
- アセットはCDNから取得する
- パフォーマンスに配慮し、高速に動作するようにする
- モバイルデバイスでも快適に閲覧できるようにレスポンシブデザインを適用する

## 制約事項
- Reveal.jsを使用すること
- お題に沿った内容であること
- 指定された要件を満たすこと

## 納期
- 要相談

## 予算
- 100万円相当の価値を提供できるよう努める
